/*
 *  Copyright (C) 2008 Patrik Gornicz, Gornicz_P (at) hotmail (dot) com.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "GravityWell.h"
#include "Entities/PhysicsEntity.h"

float wellGravity = 0.5;

/// ***** Constructors/Destructors *****

GravityWell::GravityWell(const Vector2& pos)
    : position(pos)
{

}
GravityWell::~GravityWell()
{

}

/// ***** Public Class Methods *****

Vector2 GravityWell::forceDelta(const PhysicsEntity* e, float) const
{
    const Vector2& pos = e->positionRaw();
    float mass = e->m_mass;

    Vector2 delta = position - pos;
    float sqrDist = delta.sqrLength();

    Vector2 acc(0,0);

    if( sqrDist > 0.5F )
        acc += delta / sqrDist * mass * wellGravity;

    return acc;
}

void GravityWell::setPosition(const Vector2& pos)
{
    position = pos;
}
